Physiology
==========================

These modules provide tools for analysis of physiology in fNIRS and fNIRS auxiliary data

.. autosummary::
   :toctree: _autosummary_models
   :recursive:

    cedalion.sigproc.physio.ampd
    cedalion.sigproc.physio.global_component_subtract


Examples
--------

.. nbgallery::
   :glob:

   ../examples/physio/*
   ../examples/signal_quality/24_downweighting_noisy_channels.ipynb